==> inventive-inventory-1.3.2-sources.jar: net/inventive_mods/inventive_inventory/keys/mixins/MixinKeyInputHandler.java <==
package net.inventive_mods.inventive_inventory.keys.mixins;


import net.inventive_mods.inventive_inventory.context.ContextManager;
import net.inventive_mods.inventive_inventory.features.sorting.SortingHandler;
import net.inventive_mods.inventive_inventory.keys.KeyRegistry;
import net.inventive_mods.inventive_inventory.keys.handler.AdvancedOperationHandler;
import net.minecraft.class_465;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfoReturnable;

@Mixin(class_465.class)
public class MixinKeyInputHandler {
    @Inject(method = "keyPressed", at = @At("HEAD"))
    private void onKeyPressed(int keyCode, int scanCode, int modifiers, CallbackInfoReturnable<Boolean> cir) {
        if (KeyRegistry.advancedOperationKey.method_1417(keyCode, scanCode)) {
            AdvancedOperationHandler.setPressed(true);
        }
        if (KeyRegistry.sortKey.method_1417(keyCode, scanCode) && ContextManager.isInit()) {
            SortingHandler.sort();
        }
    }

    @Inject(method = "onMouseClick(I)V", at = @At("HEAD"))
    private void onMouseClick(int button, CallbackInfo ci) {
        if (KeyRegistry.advancedOperationKey.method_1433(button)) {
            AdvancedOperationHandler.setPressed(true);
        }
        if (KeyRegistry.sortKey.method_1433(button) && ContextManager.isInit()) {
            SortingHandler.sort();
        }
    }

    @Inject(method = "tick", at = @At("HEAD"))
    private void onTick(CallbackInfo ci) {
        if (AdvancedOperationHandler.isReleased()) {
            AdvancedOperationHandler.setPressed(false);
        }
    }
}

==> inventive-inventory-1.3.4-sources.jar: net/inventive_mods/inventive_inventory/keys/mixins/MixinKeyInputHandler.java <==
package net.inventive_mods.inventive_inventory.keys.mixins;


import net.inventive_mods.inventive_inventory.context.ContextManager;
import net.inventive_mods.inventive_inventory.features.sorting.SortingHandler;
import net.inventive_mods.inventive_inventory.keys.KeyRegistry;
import net.inventive_mods.inventive_inventory.keys.handler.AdvancedOperationHandler;
import net.minecraft.class_11908;
import net.minecraft.class_11909;
import net.minecraft.class_465;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfoReturnable;

@Mixin(class_465.class)
public class MixinKeyInputHandler {
    @Inject(method = "keyPressed", at = @At("HEAD"))
    private void onKeyPressed(class_11908 input, CallbackInfoReturnable<Boolean> cir) {
        if (KeyRegistry.advancedOperationKey.method_1417(input)) {
            AdvancedOperationHandler.setPressed(true);
        }
        if (KeyRegistry.sortKey.method_1417(input) && ContextManager.isInit()) {
            SortingHandler.sort();
        }
    }

    @Inject(method = "onMouseClick(Lnet/minecraft/client/gui/Click;)V", at = @At("HEAD"))
    private void onMouseClick(class_11909 click, CallbackInfo ci) {
        if (KeyRegistry.advancedOperationKey.method_1433(click)) {
            AdvancedOperationHandler.setPressed(true);
        }
        if (KeyRegistry.sortKey.method_1433(click) && ContextManager.isInit()) {
            SortingHandler.sort();
        }
    }

    @Inject(method = "tick", at = @At("HEAD"))
    private void onTick(CallbackInfo ci) {
        if (AdvancedOperationHandler.isReleased()) {
            AdvancedOperationHandler.setPressed(false);
        }
    }
}
